==> knox-1.2.0-src.zip: knox-1.2.0/gateway-util-configinjector/src/test/java/org/apache/knox/gateway/config/OptionalTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.config;

import org.junit.Test;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.core.Is.is;

public class OptionalTest {

  class FieldTarget {
    @Configure
    @Optional
    private int num = -1;
  }

  class SetterTarget {
    private int num = -1;
    @Configure
    public void setNum( @Default("-1") int n ) { this.num = n; };
  }

  @Test
  public void testDefaultInject() {
    FieldTarget fieldTarget = new FieldTarget();
    ConfigurationInjectorBuilder.configuration()
        .target( fieldTarget )
        .source( System.getProperties() )
        //.bind( "user", "user.name" )
        .inject();
    assertThat( fieldTarget.num, is(-1) );

    SetterTarget setterTarget = new SetterTarget();
    ConfigurationInjectorBuilder.configuration()
        .target( setterTarget )
        .source( System.getProperties() )
            //.bind( "user", "user.name" )
        .inject();
    assertThat( fieldTarget.num, is(-1) );
  }

}

==> knox-1.6.0-src.zip: knox-1.6.0/gateway-util-configinjector/src/test/java/org/apache/knox/gateway/config/OptionalTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.config;

import org.junit.Test;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.core.Is.is;

public class OptionalTest {

  class FieldTarget {
    @Configure
    @Optional
    private int num = -1;
  }

  class SetterTarget {
    private int num = -1;
    @Configure
    public void setNum( @Default("-1") int n ) { this.num = n; }
  }

  @Test
  public void testDefaultInject() {
    FieldTarget fieldTarget = new FieldTarget();
    ConfigurationInjectorBuilder.configuration()
        .target( fieldTarget )
        .source( System.getProperties() )
        //.bind( "user", "user.name" )
        .inject();
    assertThat( fieldTarget.num, is(-1) );

    SetterTarget setterTarget = new SetterTarget();
    ConfigurationInjectorBuilder.configuration()
        .target( setterTarget )
        .source( System.getProperties() )
            //.bind( "user", "user.name" )
        .inject();
    assertThat( fieldTarget.num, is(-1) );
  }

}
